@@ -20,7 +20,6 @@
 */
 
 #include <config.h>
-#include <gtk/gtksignal.h>
 #include "htmlengine-edit-cursor.h"
 #include "htmlcolor.h"
 #include "htmldrawqueue.h"
@@ -33,7 +32,9 @@
 #include "htmlsettings.h"
 #include "gtkhtml.h"
 
-
+/* backward-compatibility cruft */
+#include "gtk-compat.h"
+
 /* HTMLDrawQueueClearElement handling.  */
 
 static HTMLDrawQueueClearElement *
@@ -257,7 +258,7 @@ html_draw_queue_flush (HTMLDrawQueue *queue)
 
 	/* check to make sure we have something to draw on */
 
-	vis = queue->engine->window ? gdk_drawable_get_visual (queue->engine->window): NULL;
+	vis = queue->engine->window ? gdk_window_get_visual (queue->engine->window): NULL;
 
 	/* Draw clear areas.  */
 
@@ -270,7 +271,6 @@ html_draw_queue_flush (HTMLDrawQueue *queue)
 		clear_element_destroy (clear_elem);
 	}
 
-
 	/* Draw objects.  */
 
 	if (vis) {
@@ -286,11 +286,3 @@ html_draw_queue_flush (HTMLDrawQueue *queue)
 	html_draw_queue_clear (queue);
 }
 
-
-
-
-
-
-
-
-
